@@ -191,7 +191,7 @@ class ModelInstance:
         self.model_id = model_id
         self.chat_history = []
         self.chat_history = self.get_chat_history()
-        self.is_deployed = self.instance_id not in models['model_id'].model_instances
+        self.is_deployed = self.instance_id not in models[self.model_id].model_instances
 
     def get_chat_history(self):
         # get chat history interactions with pagination
